--[[
An ActionButton that has a defined behavior of "do nothing".  Normally, this
shows up as a typical cancel button (x), but can show up as a menu selection
with the word "Cancel" associated with it.  Other looks are also possible.

There is one ActionButtonNone per UnitGroupHeader.
Each ActionButtonNone instance is associated with a single UnitGroupHeader.
--]]
uab.classes.ActionButtonNone = uab.mixins.aceOO.Class()

function uab.classes.ActionButtonNone.ShowTooltip(frame)
    if uab.db.profile.tooltips then
        GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
        GameTooltip:SetBackdropColor(0.1, 0.1, 0.1, 0.8)
        GameTooltip:SetText("Cancel unit action", nil, nil, nil, nil, true)
    end
end

function uab.classes.ActionButtonNone.prototype:init(header)
	uab.classes.ActionButtonNone.super.prototype.init(self)
	
	self.header = header
    self.framename = self.header.name.."ActionBtnNone"

    self.frame = getglobal(self.framename)

    if not self.frame then    
    	--[[
    	Create frame
    	--]]
        self.frame = CreateFrame("Button", self.framename, nil, "UAB_StandardCancelButtonTemplate")
    end
    
    self.frame.uabobj = self
    self.frame:Show()

    uab.SetBoolFrameAttribute(self.frame, "useparent-unit", true)
    uab.SetBoolFrameAttribute(self.frame, "useparent-unitsuffix", true)
    uab.SetFrameAttribute(self.frame, "state", "0")

    self:Enable()
	self:SetParent()
    
    self.frame:SetPoint("CENTER", 0, 0)
    self.frame:SetScript("OnEnter", function(self, motion) uab.classes.ActionButtonNone.ShowTooltip(self) end)
    self.frame:SetScript("OnShow", function(self)
        self.uabobj:OnShow()
    end)
    self.frame:SetScript("OnLeave", function(self, motion) GameTooltip:Hide() end)
    
    self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:SetParent()
    if self.header.frame then
        self.frame:SetParent(self.header.frame)
	    uab.SetFrameFrameAttribute(self.header.frame, "addchild", self.frame)
    end
end

function uab.classes.ActionButtonNone.prototype:Show()
	-- Nothing to do here, since this is the cancel button, which does not
	-- change visual appearance.
end

function uab.classes.ActionButtonNone.prototype:Hide()
	self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:Enable()
    uab.SetFrameAttribute(self.frame, "showstates", (self.header.states.offset + self.header.states.min).."-"..(self.header.states.offset + self.header.states.max))
    uab.SetFrameAttribute(self.frame, "hidestates", nil)
    uab.SetFrameAttribute(self.frame, "newstate", "*:0")
	self.enabled = true
end

function uab.classes.ActionButtonNone.prototype:Disable()
    uab.SetFrameAttribute(self.frame, "showstates", nil)
    uab.SetFrameAttribute(self.frame, "hidestates", "*")
    uab.SetFrameAttribute(self.frame, "newstate", "*:0")
	self.enabled = nil
end

function uab.classes.ActionButtonNone.prototype:Frame()
	return self.frame
end

function uab.classes.ActionButtonNone.prototype:OnShow()
    self.frame:SetFrameStrata("FULLSCREEN_DIALOG")
end

